/**
 * oscP5sendreceive by andreas schlegel
 * example shows how to send and receive osc messages.
 * oscP5 website at http://www.sojamo.de/oscP5
 */
import gab.opencv.*;
import processing.video.*;
import java.awt.*; 
Capture video;
OpenCV opencv;

import oscP5.*;
import netP5.*;
import processing.serial.*; 
OscP5 oscP5;
NetAddress myRemoteLocation;
Serial myPort;  // Create object from Serial class
int counter = 0;
int counter2 = 0;

void setup() {
  size(640,480);
  frameRate(25);
  /* start oscP5, listening for incoming messages at port 8000 */
  oscP5 = new OscP5(this,8000);
  String portName = Serial.list()[0]; //change to the 0 port
  myPort = new Serial(this, portName, 19200);
  /* myRemoteLocation is a NetAddress. a NetAddress takes 2 parameters,
   * an ip address and a port number. myRemoteLocation is used as parameter in
   * oscP5.send() when sending osc packets to another computer, device, 
   * application. usage see below. for testing purposes the listening port
   * and the port of the remote location address are the same, hence you will
   * send messages back to this sketch.
   */
  myRemoteLocation = new NetAddress("127.0.0.1",12000);
  
  video = new Capture(this, 640/2, 480/2, "Logitech HD Webcam C270");
  opencv = new OpenCV(this, 640/2, 480/2);
  opencv.loadCascade(OpenCV.CASCADE_MOUTH);  

  video.start();
}

void draw() {
  //background(0);  

  scale(2);
  opencv.loadImage(video);

  image(video, 0, 0 );

  noFill();
  stroke(0, 255, 0);
  strokeWeight(3);
  
  //double scaleFactor=1.1, int minNeighbors=3, int flags=0, Size minSize=Size(), Size maxSize=Size()
  Rectangle[] mouth = opencv.detect(1.1, 200, 0, 0, 200);
  //println(mouth.length);

  for (int i = 0; i < mouth.length; i++) {
    
    //println("linksx=" + mouth[i].x + ", obeny=" + mouth[i].y);
    
    rect(mouth[i].x, mouth[i].y, mouth[i].width, mouth[i].height);
    
    //println("b=" + mouth[i].width + ", h=" + mouth[i].height);
    
    float z = (400*5.7)/mouth[i].width;                          // z = Entfernung Kamera-Mund [cm]
    
    float xCam = (mouth[i].x+((mouth[i].width)/2)-160);          // xCam = x-Achsenabschnitt im Kamerabild [px]
    float yCam = (mouth[i].y+((mouth[i].height)/2)-120);         // yCam = y-achsenabschnitt im Kamerabild [px]
    
    println("x=" + xCam + "y=" + yCam);

    float x = z*(xCam/400);                                      // x = x-Abstand zur Bildmitte [cm]
    float y = z*(yCam/400);                                      // y = y-Abstand zur Bildmitte [cm]

    //println("Entfernung[cm]: d=" + z);
    
    println("x=" + x + " | y=" + y + " | z=" + z);
    
   
}
}

void captureEvent(Capture c) {
  c.read();
}

void mousePressed() {
  
  /* in the following different ways of creating osc messages are shown by example */
  OscMessage myMessage = new OscMessage("/test");
  
  myMessage.add(123); /* add an int to the osc message */

  /* send the message */
  oscP5.send(myMessage, myRemoteLocation); 
}


/* incoming osc message are forwarded to the oscEvent method. */
void oscEvent(OscMessage theOscMessage) {
  if (counter>=2){
    counter = 0;
  }
  if (counter2>=2){
    counter2 = 0;
  }
  
  /* print the address pattern and the typetag of the received OscMessage */

  if(theOscMessage.checkAddrPattern("/1/toggle1")){
    counter2 = counter2 + 1;
    print("Toggle was used\n");
    println(counter2);
    if(counter2 == 1){
      myPort.write('3');
    }
     /*
     float servo1 = 90.0;
     float servo2 = 90.0;
     float servo3 = 90.0;
 
     myPort.write('w1'+str(servo1)+"\n");
     myPort.write('w2'+str(servo2)+"\n");
     myPort.write('w3'+str(servo3)+"\n");
    */
    else{
      myPort.write('4');
    }
    
  }
  else if(theOscMessage.checkAddrPattern("/1/push1")){
   counter = counter + 1;
  
    print("The button has been pressed\n");

                            
   if(counter == 1){
     myPort.write('1');         //send a 1
   println(counter);   
  } 
  else {                           //otherwise
  myPort.write('2');          //send a 0
  println('2');
    }
  }
}